@@ -25,7 +25,7 @@ test_that(".coo_angle_edge1 works fine", {
   sq_ang <- matrix(c(0, 1, 0, 0, 1, 0), ncol=2, byrow=TRUE)
   expect_is(.coo_angle_edge1(sq_ang),
             "numeric")
-  expect_true(coo_angle_edge1(sq_ang)<0)
+  expect_true(.coo_angle_edge1(sq_ang)<0)
   expect_true(.coo_angle_edge1(sq_ang, "acos")>0)
   expect_error(.coo_angle_edge1(bot))
   expect_error(.coo_angle_edge1(bot[1][1:4, ]))
